==========================================================
Internet Calendaring and Scheduling (iCalendar) for Python
==========================================================

The `icalendar`_ package is a parser/generator of iCalendar files for use
with Python.

----

    :Code: http://github.com/collective/icalendar
    :Mailing list: http://github.com/collective/icalendar/issues
    :Dependencies: There are no other dependencies.
    :Tested with: Python 2.4 - 2.7
    :License: ???

----


About this fork which is not a fork anymore
===========================================

Aim of this fork was to bring this package up to date with latest icalendar
`RFC`_ specification as part of `plone.app.event`_ project which goal is to
bring recurrent evens to `Plone`_.

After some thoughts we (Plone developers involved with `plone.app.event`_) send
a suggestion to icalendar-dev@codespeak.net to take over mainaining of
`icalendar`_. Nobody object and since version 2.2 we are back to development.


.. _`icalendar`: http://pypi.python.org/pypi/icalendar
.. _`plone.app.event`: http://github.com/collective/plone.app.event
.. _`Plone`: http://plone.org
.. _`RFC`: http://www.ietf.org/rfc/rfc5545.txt

